# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from tester_sdk.models.gif_images import GifImages
from tester_sdk.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Gif(BaseModel):
    """
    Gif
    """ # noqa: E501
    bitly_url: Optional[StrictStr] = Field(default=None, description="The unique bit.ly URL for this GIF")
    content_url: Optional[StrictStr] = Field(default=None, description="Currently unused")
    create_datetime: Optional[datetime] = Field(default=None, description="The date this GIF was added to the GIPHY database.")
    embded_url: Optional[StrictStr] = Field(default=None, description="A URL used for embedding this GIF")
    featured_tags: Optional[List[StrictStr]] = Field(default=None, description="An array of featured tags for this GIF (Note: Not available when using the Public Beta Key) ")
    id: Optional[StrictStr] = Field(default=None, description="This GIF's unique ID")
    images: Optional[GifImages] = None
    import_datetime: Optional[datetime] = Field(default=None, description="The creation or upload date from this GIF's source.")
    rating: Optional[StrictStr] = Field(default=None, description="The MPAA-style rating for this content. Examples include Y, G, PG, PG-13 and R")
    slug: Optional[StrictStr] = Field(default=None, description="The unique slug used in this GIF's URL")
    source: Optional[StrictStr] = Field(default=None, description="The page on which this GIF was found")
    source_post_url: Optional[StrictStr] = Field(default=None, description="The URL of the webpage on which this GIF was found.")
    source_tld: Optional[StrictStr] = Field(default=None, description="The top level domain of the source URL.")
    tags: Optional[List[StrictStr]] = Field(default=None, description="An array of tags for this GIF (Note: Not available when using the Public Beta Key) ")
    type: Optional[StrictStr] = Field(default='gif', description="Type of the gif. By default, this is almost always gif")
    update_datetime: Optional[datetime] = Field(default=None, description="The date on which this GIF was last updated.")
    url: Optional[StrictStr] = Field(default=None, description="The unique URL for this GIF")
    user: Optional[User] = None
    username: Optional[StrictStr] = Field(default=None, description="The username this GIF is attached to, if applicable")
    __properties: ClassVar[List[str]] = ["bitly_url", "content_url", "create_datetime", "embded_url", "featured_tags", "id", "images", "import_datetime", "rating", "slug", "source", "source_post_url", "source_tld", "tags", "type", "update_datetime", "url", "user", "username"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['gif']):
            raise ValueError("must be one of enum values ('gif')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Gif from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of images
        if self.images:
            _dict['images'] = self.images.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Gif from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bitly_url": obj.get("bitly_url"),
            "content_url": obj.get("content_url"),
            "create_datetime": obj.get("create_datetime"),
            "embded_url": obj.get("embded_url"),
            "featured_tags": obj.get("featured_tags"),
            "id": obj.get("id"),
            "images": GifImages.from_dict(obj["images"]) if obj.get("images") is not None else None,
            "import_datetime": obj.get("import_datetime"),
            "rating": obj.get("rating"),
            "slug": obj.get("slug"),
            "source": obj.get("source"),
            "source_post_url": obj.get("source_post_url"),
            "source_tld": obj.get("source_tld"),
            "tags": obj.get("tags"),
            "type": obj.get("type") if obj.get("type") is not None else 'gif',
            "update_datetime": obj.get("update_datetime"),
            "url": obj.get("url"),
            "user": User.from_dict(obj["user"]) if obj.get("user") is not None else None,
            "username": obj.get("username")
        })
        return _obj





# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.models.image import Image

class TestImage(unittest.TestCase):
    """Image unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Image:
        """Test Image
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Image`
        """
        model = Image()
        if include_optional:
            return Image(
                frames = '15',
                height = '200',
                mp4 = 'https://media1.giphy.com/media/cZ7rmKfFYOvYI/giphy.mp4',
                mp4_size = '25123',
                size = '32381',
                url = 'https://media1.giphy.com/media/cZ7rmKfFYOvYI/200.gif',
                webp = 'https://media1.giphy.com/media/cZ7rmKfFYOvYI/giphy.webp',
                webp_size = '12321',
                width = '320'
            )
        else:
            return Image(
        )
        """

    def testImage(self):
        """Test Image"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.models.gif_images import GifImages

class TestGifImages(unittest.TestCase):
    """GifImages unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GifImages:
        """Test GifImages
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GifImages`
        """
        model = GifImages()
        if include_optional:
            return GifImages(
                downsized = None,
                downsized_large = None,
                downsized_medium = None,
                downsized_small = None,
                downsized_still = None,
                fixed_height = None,
                fixed_height_downsampled = None,
                fixed_height_small = None,
                fixed_height_small_still = None,
                fixed_height_still = None,
                fixed_width = None,
                fixed_width_downsampled = None,
                fixed_width_small = None,
                fixed_width_small_still = None,
                fixed_width_still = None,
                looping = None,
                original = None,
                original_still = None,
                preview = None,
                preview_gif = None
            )
        else:
            return GifImages(
        )
        """

    def testGifImages(self):
        """Test GifImages"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.models.get_gifs_by_id200_response import GetGifsById200Response

class TestGetGifsById200Response(unittest.TestCase):
    """GetGifsById200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetGifsById200Response:
        """Test GetGifsById200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetGifsById200Response`
        """
        model = GetGifsById200Response()
        if include_optional:
            return GetGifsById200Response(
                data = [
                    tester_sdk.models.gif.Gif(
                        bitly_url = 'http://gph.is/1gsWDcL', 
                        content_url = '', 
                        create_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        embded_url = 'http://giphy.com/embed/YsTs5ltWtEhnq', 
                        featured_tags = [
                            ''
                            ], 
                        id = 'YsTs5ltWtEhnq', 
                        images = tester_sdk.models.gif_images.Gif_images(
                            downsized = null, 
                            downsized_large = null, 
                            downsized_medium = null, 
                            downsized_small = null, 
                            downsized_still = null, 
                            fixed_height = null, 
                            fixed_height_downsampled = null, 
                            fixed_height_small = null, 
                            fixed_height_small_still = null, 
                            fixed_height_still = null, 
                            fixed_width = null, 
                            fixed_width_downsampled = null, 
                            fixed_width_small = null, 
                            fixed_width_small_still = null, 
                            fixed_width_still = null, 
                            looping = null, 
                            original = null, 
                            original_still = null, 
                            preview = null, 
                            preview_gif = null, ), 
                        import_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        rating = 'g', 
                        slug = 'confused-flying-YsTs5ltWtEhnq', 
                        source = 'http://www.reddit.com/r/reactiongifs/comments/1xpyaa/superman_goes_to_hollywood/', 
                        source_post_url = 'http://cheezburger.com/5282328320', 
                        source_tld = 'cheezburger.com', 
                        tags = [
                            ''
                            ], 
                        type = 'gif', 
                        update_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = 'http://giphy.com/gifs/confused-flying-YsTs5ltWtEhnq', 
                        user = tester_sdk.models.user.User(
                            avatar_url = 'https://media1.giphy.com/avatars/election2016/XwYrZi5H87o6.gif', 
                            banner_url = 'https://media4.giphy.com/avatars/cheezburger/XkuejOhoGLE6.jpg', 
                            display_name = 'JoeCool4000', 
                            profile_url = 'https://giphy.com/cheezburger/', 
                            twitter = '@joecool4000', 
                            username = 'joecool4000', ), 
                        username = 'JoeCool4000', )
                    ],
                meta = tester_sdk.models.meta.Meta(
                    msg = 'OK', 
                    response_id = '57eea03c72381f86e05c35d2', 
                    status = 200, ),
                pagination = tester_sdk.models.pagination.Pagination(
                    count = 25, 
                    offset = 75, 
                    total_count = 250, )
            )
        else:
            return GetGifsById200Response(
        )
        """

    def testGetGifsById200Response(self):
        """Test GetGifsById200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.api.gifs_api import GifsApi


class TestGifsApi(unittest.TestCase):
    """GifsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GifsApi()

    def tearDown(self) -> None:
        pass

    def test_get_gif_by_id(self) -> None:
        """Test case for get_gif_by_id

        Get GIF by Id
        """
        pass

    def test_get_gifs_by_id(self) -> None:
        """Test case for get_gifs_by_id

        Get GIFs by ID
        """
        pass

    def test_random_gif(self) -> None:
        """Test case for random_gif

        Random GIF
        """
        pass

    def test_search_gifs(self) -> None:
        """Test case for search_gifs

        Search GIFs
        """
        pass

    def test_translate_gif(self) -> None:
        """Test case for translate_gif

        Translate phrase to GIF
        """
        pass

    def test_trending_gifs(self) -> None:
        """Test case for trending_gifs

        Trending GIFs
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from tester_sdk.models.get_gifs_by_id200_response import GetGifsById200Response
from tester_sdk.models.random_gif200_response import RandomGif200Response

from tester_sdk.api_client import ApiClient, RequestSerialized
from tester_sdk.api_response import ApiResponse
from tester_sdk.rest import RESTResponseType


class StickersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def random_sticker(
        self,
        tag: Annotated[Optional[StrictStr], Field(description="Filters results by specified tag.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RandomGif200Response:
        """Random Sticker

        Returns a random GIF, limited by tag. Excluding the tag parameter will return a random GIF from the GIPHY catalog. 

        :param tag: Filters results by specified tag.
        :type tag: str
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._random_sticker_serialize(
            tag=tag,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def random_sticker_with_http_info(
        self,
        tag: Annotated[Optional[StrictStr], Field(description="Filters results by specified tag.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[RandomGif200Response]:
        """Random Sticker

        Returns a random GIF, limited by tag. Excluding the tag parameter will return a random GIF from the GIPHY catalog. 

        :param tag: Filters results by specified tag.
        :type tag: str
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._random_sticker_serialize(
            tag=tag,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def random_sticker_without_preload_content(
        self,
        tag: Annotated[Optional[StrictStr], Field(description="Filters results by specified tag.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Random Sticker

        Returns a random GIF, limited by tag. Excluding the tag parameter will return a random GIF from the GIPHY catalog. 

        :param tag: Filters results by specified tag.
        :type tag: str
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._random_sticker_serialize(
            tag=tag,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _random_sticker_serialize(
        self,
        tag,
        rating,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if tag is not None:
            
            _query_params.append(('tag', tag))
            
        if rating is not None:
            
            _query_params.append(('rating', rating))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/random',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def search_stickers(
        self,
        q: Annotated[StrictStr, Field(description="Search query term or prhase.")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        lang: Annotated[Optional[StrictStr], Field(description="Specify default language for regional content; use a 2-letter ISO 639-1 language code.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> GetGifsById200Response:
        """Search Stickers

        Replicates the functionality and requirements of the classic GIPHY search, but returns animated stickers rather than GIFs. 

        :param q: Search query term or prhase. (required)
        :type q: str
        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :param lang: Specify default language for regional content; use a 2-letter ISO 639-1 language code.
        :type lang: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_stickers_serialize(
            q=q,
            limit=limit,
            offset=offset,
            rating=rating,
            lang=lang,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_stickers_with_http_info(
        self,
        q: Annotated[StrictStr, Field(description="Search query term or prhase.")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        lang: Annotated[Optional[StrictStr], Field(description="Specify default language for regional content; use a 2-letter ISO 639-1 language code.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[GetGifsById200Response]:
        """Search Stickers

        Replicates the functionality and requirements of the classic GIPHY search, but returns animated stickers rather than GIFs. 

        :param q: Search query term or prhase. (required)
        :type q: str
        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :param lang: Specify default language for regional content; use a 2-letter ISO 639-1 language code.
        :type lang: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_stickers_serialize(
            q=q,
            limit=limit,
            offset=offset,
            rating=rating,
            lang=lang,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_stickers_without_preload_content(
        self,
        q: Annotated[StrictStr, Field(description="Search query term or prhase.")],
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        lang: Annotated[Optional[StrictStr], Field(description="Specify default language for regional content; use a 2-letter ISO 639-1 language code.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Search Stickers

        Replicates the functionality and requirements of the classic GIPHY search, but returns animated stickers rather than GIFs. 

        :param q: Search query term or prhase. (required)
        :type q: str
        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :param lang: Specify default language for regional content; use a 2-letter ISO 639-1 language code.
        :type lang: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_stickers_serialize(
            q=q,
            limit=limit,
            offset=offset,
            rating=rating,
            lang=lang,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _search_stickers_serialize(
        self,
        q,
        limit,
        offset,
        rating,
        lang,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if rating is not None:
            
            _query_params.append(('rating', rating))
            
        if lang is not None:
            
            _query_params.append(('lang', lang))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def translate_sticker(
        self,
        s: Annotated[StrictStr, Field(description="Search term.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RandomGif200Response:
        """Translate phrase to Sticker

        The translate API draws on search, but uses the GIPHY `special sauce` to handle translating from one vocabulary to another. In this case, words and phrases to GIFs. 

        :param s: Search term. (required)
        :type s: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_sticker_serialize(
            s=s,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def translate_sticker_with_http_info(
        self,
        s: Annotated[StrictStr, Field(description="Search term.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[RandomGif200Response]:
        """Translate phrase to Sticker

        The translate API draws on search, but uses the GIPHY `special sauce` to handle translating from one vocabulary to another. In this case, words and phrases to GIFs. 

        :param s: Search term. (required)
        :type s: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_sticker_serialize(
            s=s,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def translate_sticker_without_preload_content(
        self,
        s: Annotated[StrictStr, Field(description="Search term.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Translate phrase to Sticker

        The translate API draws on search, but uses the GIPHY `special sauce` to handle translating from one vocabulary to another. In this case, words and phrases to GIFs. 

        :param s: Search term. (required)
        :type s: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._translate_sticker_serialize(
            s=s,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RandomGif200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _translate_sticker_serialize(
        self,
        s,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if s is not None:
            
            _query_params.append(('s', s))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/translate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def trending_stickers(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> GetGifsById200Response:
        """Trending Stickers

        Fetch Stickers currently trending online. Hand curated by the GIPHY editorial team. Returns 25 results by default. 

        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._trending_stickers_serialize(
            limit=limit,
            offset=offset,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def trending_stickers_with_http_info(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[GetGifsById200Response]:
        """Trending Stickers

        Fetch Stickers currently trending online. Hand curated by the GIPHY editorial team. Returns 25 results by default. 

        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._trending_stickers_serialize(
            limit=limit,
            offset=offset,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def trending_stickers_without_preload_content(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of records to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="An optional results offset.")] = None,
        rating: Annotated[Optional[StrictStr], Field(description="Filters results by specified rating.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """Trending Stickers

        Fetch Stickers currently trending online. Hand curated by the GIPHY editorial team. Returns 25 results by default. 

        :param limit: The maximum number of records to return.
        :type limit: int
        :param offset: An optional results offset.
        :type offset: int
        :param rating: Filters results by specified rating.
        :type rating: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._trending_stickers_serialize(
            limit=limit,
            offset=offset,
            rating=rating,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetGifsById200Response",
            '400': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _trending_stickers_serialize(
        self,
        limit,
        offset,
        rating,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if rating is not None:
            
            _query_params.append(('rating', rating))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api_key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/stickers/trending',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from tester_sdk.models.gif_images_downsized import GifImagesDownsized
from tester_sdk.models.gif_images_downsized_large import GifImagesDownsizedLarge
from tester_sdk.models.gif_images_downsized_medium import GifImagesDownsizedMedium
from tester_sdk.models.gif_images_downsized_small import GifImagesDownsizedSmall
from tester_sdk.models.gif_images_downsized_still import GifImagesDownsizedStill
from tester_sdk.models.gif_images_fixed_height import GifImagesFixedHeight
from tester_sdk.models.gif_images_fixed_height_downsampled import GifImagesFixedHeightDownsampled
from tester_sdk.models.gif_images_fixed_height_small import GifImagesFixedHeightSmall
from tester_sdk.models.gif_images_fixed_height_small_still import GifImagesFixedHeightSmallStill
from tester_sdk.models.gif_images_fixed_height_still import GifImagesFixedHeightStill
from tester_sdk.models.gif_images_fixed_width import GifImagesFixedWidth
from tester_sdk.models.gif_images_fixed_width_downsampled import GifImagesFixedWidthDownsampled
from tester_sdk.models.gif_images_fixed_width_small import GifImagesFixedWidthSmall
from tester_sdk.models.gif_images_fixed_width_small_still import GifImagesFixedWidthSmallStill
from tester_sdk.models.gif_images_fixed_width_still import GifImagesFixedWidthStill
from tester_sdk.models.gif_images_looping import GifImagesLooping
from tester_sdk.models.gif_images_original import GifImagesOriginal
from tester_sdk.models.gif_images_original_still import GifImagesOriginalStill
from tester_sdk.models.gif_images_preview import GifImagesPreview
from tester_sdk.models.gif_images_preview_gif import GifImagesPreviewGif
from typing import Optional, Set
from typing_extensions import Self

class GifImages(BaseModel):
    """
    An object containing data for various available formats and sizes of this GIF.
    """ # noqa: E501
    downsized: Optional[GifImagesDownsized] = None
    downsized_large: Optional[GifImagesDownsizedLarge] = None
    downsized_medium: Optional[GifImagesDownsizedMedium] = None
    downsized_small: Optional[GifImagesDownsizedSmall] = None
    downsized_still: Optional[GifImagesDownsizedStill] = None
    fixed_height: Optional[GifImagesFixedHeight] = None
    fixed_height_downsampled: Optional[GifImagesFixedHeightDownsampled] = None
    fixed_height_small: Optional[GifImagesFixedHeightSmall] = None
    fixed_height_small_still: Optional[GifImagesFixedHeightSmallStill] = None
    fixed_height_still: Optional[GifImagesFixedHeightStill] = None
    fixed_width: Optional[GifImagesFixedWidth] = None
    fixed_width_downsampled: Optional[GifImagesFixedWidthDownsampled] = None
    fixed_width_small: Optional[GifImagesFixedWidthSmall] = None
    fixed_width_small_still: Optional[GifImagesFixedWidthSmallStill] = None
    fixed_width_still: Optional[GifImagesFixedWidthStill] = None
    looping: Optional[GifImagesLooping] = None
    original: Optional[GifImagesOriginal] = None
    original_still: Optional[GifImagesOriginalStill] = None
    preview: Optional[GifImagesPreview] = None
    preview_gif: Optional[GifImagesPreviewGif] = None
    __properties: ClassVar[List[str]] = ["downsized", "downsized_large", "downsized_medium", "downsized_small", "downsized_still", "fixed_height", "fixed_height_downsampled", "fixed_height_small", "fixed_height_small_still", "fixed_height_still", "fixed_width", "fixed_width_downsampled", "fixed_width_small", "fixed_width_small_still", "fixed_width_still", "looping", "original", "original_still", "preview", "preview_gif"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GifImages from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of downsized
        if self.downsized:
            _dict['downsized'] = self.downsized.to_dict()
        # override the default output from pydantic by calling `to_dict()` of downsized_large
        if self.downsized_large:
            _dict['downsized_large'] = self.downsized_large.to_dict()
        # override the default output from pydantic by calling `to_dict()` of downsized_medium
        if self.downsized_medium:
            _dict['downsized_medium'] = self.downsized_medium.to_dict()
        # override the default output from pydantic by calling `to_dict()` of downsized_small
        if self.downsized_small:
            _dict['downsized_small'] = self.downsized_small.to_dict()
        # override the default output from pydantic by calling `to_dict()` of downsized_still
        if self.downsized_still:
            _dict['downsized_still'] = self.downsized_still.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_height
        if self.fixed_height:
            _dict['fixed_height'] = self.fixed_height.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_height_downsampled
        if self.fixed_height_downsampled:
            _dict['fixed_height_downsampled'] = self.fixed_height_downsampled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_height_small
        if self.fixed_height_small:
            _dict['fixed_height_small'] = self.fixed_height_small.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_height_small_still
        if self.fixed_height_small_still:
            _dict['fixed_height_small_still'] = self.fixed_height_small_still.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_height_still
        if self.fixed_height_still:
            _dict['fixed_height_still'] = self.fixed_height_still.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_width
        if self.fixed_width:
            _dict['fixed_width'] = self.fixed_width.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_width_downsampled
        if self.fixed_width_downsampled:
            _dict['fixed_width_downsampled'] = self.fixed_width_downsampled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_width_small
        if self.fixed_width_small:
            _dict['fixed_width_small'] = self.fixed_width_small.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_width_small_still
        if self.fixed_width_small_still:
            _dict['fixed_width_small_still'] = self.fixed_width_small_still.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fixed_width_still
        if self.fixed_width_still:
            _dict['fixed_width_still'] = self.fixed_width_still.to_dict()
        # override the default output from pydantic by calling `to_dict()` of looping
        if self.looping:
            _dict['looping'] = self.looping.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original
        if self.original:
            _dict['original'] = self.original.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original_still
        if self.original_still:
            _dict['original_still'] = self.original_still.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preview
        if self.preview:
            _dict['preview'] = self.preview.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preview_gif
        if self.preview_gif:
            _dict['preview_gif'] = self.preview_gif.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GifImages from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "downsized": GifImagesDownsized.from_dict(obj["downsized"]) if obj.get("downsized") is not None else None,
            "downsized_large": GifImagesDownsizedLarge.from_dict(obj["downsized_large"]) if obj.get("downsized_large") is not None else None,
            "downsized_medium": GifImagesDownsizedMedium.from_dict(obj["downsized_medium"]) if obj.get("downsized_medium") is not None else None,
            "downsized_small": GifImagesDownsizedSmall.from_dict(obj["downsized_small"]) if obj.get("downsized_small") is not None else None,
            "downsized_still": GifImagesDownsizedStill.from_dict(obj["downsized_still"]) if obj.get("downsized_still") is not None else None,
            "fixed_height": GifImagesFixedHeight.from_dict(obj["fixed_height"]) if obj.get("fixed_height") is not None else None,
            "fixed_height_downsampled": GifImagesFixedHeightDownsampled.from_dict(obj["fixed_height_downsampled"]) if obj.get("fixed_height_downsampled") is not None else None,
            "fixed_height_small": GifImagesFixedHeightSmall.from_dict(obj["fixed_height_small"]) if obj.get("fixed_height_small") is not None else None,
            "fixed_height_small_still": GifImagesFixedHeightSmallStill.from_dict(obj["fixed_height_small_still"]) if obj.get("fixed_height_small_still") is not None else None,
            "fixed_height_still": GifImagesFixedHeightStill.from_dict(obj["fixed_height_still"]) if obj.get("fixed_height_still") is not None else None,
            "fixed_width": GifImagesFixedWidth.from_dict(obj["fixed_width"]) if obj.get("fixed_width") is not None else None,
            "fixed_width_downsampled": GifImagesFixedWidthDownsampled.from_dict(obj["fixed_width_downsampled"]) if obj.get("fixed_width_downsampled") is not None else None,
            "fixed_width_small": GifImagesFixedWidthSmall.from_dict(obj["fixed_width_small"]) if obj.get("fixed_width_small") is not None else None,
            "fixed_width_small_still": GifImagesFixedWidthSmallStill.from_dict(obj["fixed_width_small_still"]) if obj.get("fixed_width_small_still") is not None else None,
            "fixed_width_still": GifImagesFixedWidthStill.from_dict(obj["fixed_width_still"]) if obj.get("fixed_width_still") is not None else None,
            "looping": GifImagesLooping.from_dict(obj["looping"]) if obj.get("looping") is not None else None,
            "original": GifImagesOriginal.from_dict(obj["original"]) if obj.get("original") is not None else None,
            "original_still": GifImagesOriginalStill.from_dict(obj["original_still"]) if obj.get("original_still") is not None else None,
            "preview": GifImagesPreview.from_dict(obj["preview"]) if obj.get("preview") is not None else None,
            "preview_gif": GifImagesPreviewGif.from_dict(obj["preview_gif"]) if obj.get("preview_gif") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tester_sdk.api.stickers_api import StickersApi


class TestStickersApi(unittest.TestCase):
    """StickersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StickersApi()

    def tearDown(self) -> None:
        pass

    def test_random_sticker(self) -> None:
        """Test case for random_sticker

        Random Sticker
        """
        pass

    def test_search_stickers(self) -> None:
        """Test case for search_stickers

        Search Stickers
        """
        pass

    def test_translate_sticker(self) -> None:
        """Test case for translate_sticker

        Translate phrase to Sticker
        """
        pass

    def test_trending_stickers(self) -> None:
        """Test case for trending_stickers

        Trending Stickers
        """
        pass


if __name__ == '__main__':
    unittest.main()
